@@ -53,12 +53,13 @@ def build_img(docker_path, file_path=None):
     :param file_path: str: optional name of Dockerfile
     :return: str: id of the new image
     """
-
-    opts = ['-f', file_path] if file_path else []
+    img = utils.random_string(6)
+    tag = utils.random_string(6)
+    img_tag = '{}:{}'.format(img, tag)
+    opts = ['-t', img_tag ,'-f', file_path] if file_path else ['-t', img_tag]
     args = ['docker', 'build'] + opts + [docker_path]
     output = _run_live(args)
-    return _grab_built_image_id(output)
-
+    return _get_img_id_from_img_tag(img_tag)
 
 def run_container(full_docker_path, image_id, host_port=None,
                   envvars_map=None, volume_map=None, name=None):
@@ -192,6 +193,18 @@ def compose_version():
     return _run_quiet(args).split()[-1]
 
 
+def _get_img_id_from_img_tag(img_tag):
+    """
+    Get image id for a given image tag
+    :param img_tag: str: image tag
+    :return image id
+    """
+    opts = ['-q']
+    args = ['docker', 'images'] + opts +[img_tag]
+    output = _run_quiet(args)
+    return output.split()[0]
+
+
 def _get_network_settings(container_id):
     info = get_container_lowlvl_info(container_id)
     return info[NETWORK_SETTINGS_KEY]
@@ -202,12 +215,6 @@ def _pull_img(img):
     return _run_live(args)
 
 
-def _grab_built_image_id(build_output):
-    last_line = build_output.split()[-1]
-    image_id = last_line.split()[-1]
-    return image_id
-
-
 def _run_container(image_id, container_port, host_port, envvars_map,
                    volume_map, name):
     port_mapping = '{}:{}'.format(host_port, container_port)
