@@ -1,4 +1,4 @@
-# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2014 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -11,9 +11,9 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 
-from ..core.abstractcontroller import AbstractBaseController
-from ..resources.strings import strings
-from ..operations import consoleops
+from ebcli.core.abstractcontroller import AbstractBaseController
+from ebcli.resources.strings import strings
+from ebcli.operations import consoleops
 
 
 class ConsoleController(AbstractBaseController):
@@ -26,4 +26,4 @@ class ConsoleController(AbstractBaseController):
         app_name = self.get_app_name()
         env_name = self.get_env_name(noerror=True)
 
-        consoleops.open_console(app_name, env_name)
\ No newline at end of file
+        consoleops.open_console(app_name, env_name)
