@@ -1,4 +1,4 @@
-# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -11,12 +11,12 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 
-from ..core import io
-from ..core.abstractcontroller import AbstractBaseController
-from ..containers import factory, log, compat
-from ..containers.container_viewmodel import ContainerViewModel
-from ..operations import localops
-from ..resources.strings import strings, flag_text
+from ebcli.core import io
+from ebcli.core.abstractcontroller import AbstractBaseController
+from ebcli.containers import factory, log, compat
+from ebcli.containers.container_viewmodel import ContainerViewModel
+from ebcli.operations import localops
+from ebcli.resources.strings import strings, flag_text
 
 
 class LocalController(AbstractBaseController):
@@ -32,7 +32,6 @@ class LocalController(AbstractBaseController):
     @classmethod
     def _add_to_handler(cls, handler):
         handler.register(cls)
-        # Register child controllers
         for child_controller in cls._get_child_controllers():
             handler.register(child_controller)
 
@@ -42,13 +41,6 @@ class LocalController(AbstractBaseController):
                 LocalPrintEnvController, LocalRunController,
                 LocalSetEnvController, LocalStatusController]
 
-    def complete_command(self, commands):
-        if len(commands) == 1:
-            aliases = [c.Meta.aliases[0] for c in self._get_child_controllers()]
-            io.echo(*aliases)
-        else:  # Need to pass to next controller
-            pass
-
 
 class LocalRunController(AbstractBaseController):
     class Meta:
@@ -76,7 +68,6 @@ class LocalRunController(AbstractBaseController):
 
 class LocalLogsController(AbstractBaseController):
     class Meta:
-        # Workaround since labels must be unique and 'logs' is already taken
         label = 'local_logs'
         description = strings['local.logs.info']
         aliases = ['logs']
