@@ -1,4 +1,4 @@
-# Copyright 2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.s
+# Copyright 2016 Amazon.com, Inc. or its affiliates. All Rights Reserved.s
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -16,9 +16,8 @@ import sys
 
 from decimal import InvalidOperation
 from ebcli.objects.platform import PlatformVersion
-from . import term
+from ebcli.display import term
 import errno
-import pprint
 from datetime import timedelta, datetime
 from copy import copy
 from collections import OrderedDict
@@ -37,7 +36,7 @@ LOG = minimal_logger(__name__)
 
 class Screen(object):
     def __init__(self):
-        self.term = None  # terminal object
+        self.term = None
         self.tables = []
         self.vertical_offset = 0
         self.horizontal_offset = 0
@@ -275,19 +274,25 @@ class Screen(object):
                     LOG.debug("Caught SIGINT and exiting gracefully from action")
                     return True
             except Exception as e:  # Should never get thrown
-                LOG.debug("Exception thrown: {0},{1}. Something strange happened and the request could not be completed."
-                             .format(type(e), e.message))
+                LOG.debug(
+                    "Exception thrown: {0},{1}. Something strange happened "
+                    "and the request could not be completed.".format(
+                        type(e),
+                        str(e)
+                    )
+                )
                 io.log_error("Something strange happened and the request could not be completed.")
                 time.sleep(4)
                 return False
 
     def reboot_instance_view(self):
-        self.prompt_and_action('instance-ID to reboot:',
-                                  ec2.reboot_instance)
+        self.prompt_and_action('instance-ID to reboot:', ec2.reboot_instance)
 
     def replace_instance_view(self):
-        self.prompt_and_action('instance-ID to replace:',
-                                  ec2.terminate_instance)
+        self.prompt_and_action(
+            'instance-ID to replace:',
+            ec2.terminate_instance
+        )
 
     def toggle_freeze(self):
         self.frozen = not self.frozen
@@ -343,11 +348,13 @@ class Screen(object):
             else:
                 countdown = " ({} secs)".format(diff)
         env_name = data.get('EnvironmentName')
-        pad_length = term.width() \
-                     - len(env_name) \
-                     - len(timestamp) \
-                     - len(countdown) \
-                     - 1
+        pad_length = (
+            term.width()
+            - len(env_name)
+            - len(timestamp)
+            - len(countdown)
+            - 1
+        )
         if lines > 2:
             banner = io.bold(' {env_name}{status}{time}{cd} ') \
                 .format(env_name=env_name,
@@ -375,7 +382,10 @@ class Screen(object):
             try:
                 platform_arn = self.env_data['PlatformArn']
                 platform_version = PlatformVersion(platform_arn)
-                platform = ' {}/{}'.format(platform_version.platform_shorthand, platform_version.platform_version)
+                platform = ' {}/{}'.format(
+                    platform_version.platform_shorthand,
+                    platform_version.platform_version
+                )
             except KeyError:
                 solutionstack = SolutionStack(self.env_data['SolutionStackName'])
                 platform = ' {}'.format(solutionstack.platform_shorthand)
@@ -401,11 +411,16 @@ class Screen(object):
             ])
             column_size = max(len(k) for k in instance_counts) + 1
             term.echo_line(
-                ''.join((s.center(column_size)
-                          for s in instance_counts)))
+                ''.join((s.center(column_size) for s in instance_counts))
+            )
             term.echo_line(
-                ''.join((io.bold((str(v).center(column_size)))
-                                 for k, v in six.iteritems(instance_counts))))
+                ''.join(
+                    (
+                        io.bold((str(v).center(column_size)))
+                        for k, v in six.iteritems(instance_counts)
+                    )
+                )
+            )
             lines -= 2
 
         return lines
@@ -424,15 +439,16 @@ class Screen(object):
         scrolled = visible_tables[0].scroll_down(reverse=reverse)
         if scrolled:
             for i in range(1, len(visible_tables)):
-                assert len(visible_tables[0].data) >= \
-                       len(visible_tables[i].data), \
+                assert(
+                    len(visible_tables[0].data) >= len(visible_tables[i].data),
                     'First table should be the largest'
+                )
                 visible_tables[i].scroll_to_id(scrolled, reverse=reverse)
 
     def scroll_over(self, reverse=False):
         if reverse and self.horizontal_offset > 0:
             self.horizontal_offset -= 1
-        elif not reverse: #and self.horizontal_offset < (self.max_columns + 2) - 1:
+        elif not reverse:
             # remove bounds check on upper limit to allow for text scrolling in causes
             self.horizontal_offset += 1
 
@@ -441,7 +457,7 @@ class Screen(object):
 
     def show_help_line(self):
         if self.help_table.visible:
-            text = '(press Q or ESC to exit)'
+            text = '(press Q or ESC to return)'
         elif self.refresh:
             text = u' (Commands: {h}elp,{q}uit, {down} {up} {left} {right})'\
                 .format(h=io.bold('H'), q=io.bold('Q'),
