@@ -1083,7 +1083,11 @@ def set_region_for_application(interactive, region, force_non_interactive, platf
 
 
 def _create_instance_role(role_name, policy_arns):
-    document = iam_documents.EC2_ASSUME_ROLE_PERMISSION
+    region = aws.get_region_name()
+    if isinstance(region, str) and region.split('-')[0] == 'cn':
+        document = iam_documents.EC2_ASSUME_ROLE_PERMISSION_CN
+    else:
+        document = iam_documents.EC2_ASSUME_ROLE_PERMISSION
     ret = iam.create_role_with_policy(role_name, document, policy_arns)
     return ret
 
