@@ -1,4 +1,4 @@
-# Copyright 2017 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2015 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -11,13 +11,12 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 
-from ..resources.statics import namespaces, option_names
-from ..lib import elasticbeanstalk
-from . import commonops
+from ebcli.resources.statics import namespaces, option_names
+from ebcli.lib import elasticbeanstalk
+from ebcli.operations import commonops
 
 
 def open_app(app_name, env_name):
-    # get cname
     env = elasticbeanstalk.get_environment(app_name=app_name, env_name=env_name)
     settings = elasticbeanstalk.describe_configuration_settings(
         app_name, env_name)
@@ -33,4 +32,4 @@ def open_app(app_name, env_name):
     else:
         ssl = False
 
-    commonops.open_webpage_in_browser(env.cname, ssl=ssl)
\ No newline at end of file
+    commonops.open_webpage_in_browser(env.cname, ssl=ssl)
